"""Top-level package for generate-tiff-offsets."""

__author__ = """Ilan Gold"""
__email__ = 'ilan_gold@hms.harvard.edu'
__version__ = '0.1.0'
from .generate_tiff_offsets import generate_tiff_offsets, get_offsets